# FILE: cygtel.tcl
#
# Configuration feature definitions for the configuration 'cygtel'
#
# Editing instructions begin at "START EDIT HERE" below.

set config [Oc_Config RunPlatform]

if {![string match [string tolower [file rootname [file tail [info script]]]] \
        [$config GetValue platform_name]]} {
    error "Configuration cache file '[info script]' 
sourced by '[$config GetValue platform_name]'"
}

########################################################################
# START EDIT HERE
# In order to properly build, install, and run on your computing 
# platform, the OOMMF software must know certain features of your
# computing environment.  In this file are lines which set the value of 
# certain features of your computing environment.  Each line looks like:
#
# $config SetValue <feature> {<value>}
#
# where each <feature> is the name of some feature of interest,
# and <value> is the value which is assigned to that feature in a
# description of your computing environment.  Your task is to edit
# the values as necessary to properly describe your computing 
# environment.
#
# The character '#' at the beginning of a line is a comment character.
# It causes the contents of that line to be ignored.  To select
# among lines providing alternative values for a feature, uncomment the
# line containing the proper value.
#
# The features in this file are divided into three sections.  The first
# section (REQUIRED CONFIGURATION) includes features which require you 
# to provide a value.  The second section (OPTIONAL CONFIGURATION)
# includes features which have usable default values, but which you
# may wish to customize.  The third section (ADVANCED CONFIGURATION)
# contains features which you probably do not need or want to change
# without a good reason.
########################################################################
# REQUIRED CONFIGURATION

# NOTE: The rest of the REQUIRED CONFIGURATION is required only
# for building OOMMF software from source code.  If you downloaded
# a distribution with pre-compiled executables, no more configuration
# is required.

# Set the feature 'program_compiler_c++' to the program to run on this 
# platform to compile source code files written in the language C++ into 
# object files.  Select from the choices below.  If the compiler is not 
# in your path, be sure to use the whole pathname.  Also include any 
# options required to instruct your compiler to only compile, not link.  
#
# If your compiler is not listed below, additional features will
# have to be added in the ADVANCED CONFIGURATION section below to 
# describe to the OOMMF software how to operate your compiler.  Send
# e-mail to the OOMMF developers for assistance.
#
# Microsoft Visual C++
# <URL:http://www.microsoft.com/visualc/>
# $config SetValue program_compiler_c++ {cl /nologo /c}
#
# The GNU C++ compiler 'g++'
# <URL:http://www.gnu.org/software/gcc/gcc.html>
# <URL:http://egcs.cygnus.com/>
$config SetValue program_compiler_c++ {g++ -c}


########################################################################
# OPTIONAL CONFIGURATION

# Set the feature 'path_directory_temporary' to the name of an existing 
# directory on your computer in which OOMMF software should write 
# temporary files.  All OOMMF users must have write access to this 
# directory.
#
# $config SetValue path_directory_temporary {C:\temp}
# $config SetValue path_directory_temporary {C:\}

########################################################################
# ADVANCED CONFIGURATION

# The absolute, native filename of the null device
$config SetValue path_device_null {nul:}

# Compiler option processing...
set ccbasename [file tail [lindex [$config GetValue program_compiler_c++] 0]]
if {[string match g++ $ccbasename]} {
    # CYGWIN g++ C++ compiler
    $config SetValue program_compiler_c++_option_opt {format "\"-O%s\""}
    $config SetValue program_compiler_c++_option_out {format "-o \"%s\""}
    $config SetValue program_compiler_c++_option_src {format \"%s\"}
    $config SetValue program_compiler_c++_option_inc {format "\"-I%s\""}
 
    # Compiler warnings:
    # Omitted: -Wredundant-decls -Wshadow -Wcast-align
    # I would also like to use -Wcast-qual, but casting away const is
    # needed on some occasions to provide "conceptual const" functions in
    # place of "bitwise const"; cf. p76-78 of Meyer's book, "Effective C++."
    #
    # NOTE: -Wno-uninitialized is required after -Wall by gcc 2.8+ because
    # of an apparent bug
    $config SetValue program_compiler_c++_option_warn {format "-Wall \
        -W -Wpointer-arith -Wbad-function-cast -Wwrite-strings \
        -Wstrict-prototypes -Wmissing-prototypes -Wmissing-declarations \
        -Wnested-externs -Winline -Woverloaded-virtual -Wsynth -Werror"}
    $config SetValue program_compiler_c++_option_debug {format "-g"}

    # Widest natively support floating point type
    $config SetValue program_compiler_c++_typedef_realwide "long double"

    # Other compiler properties
    $config SetValue \
            program_compiler_c++_property_optimization_breaks_varargs 0

    # Librarian: ar
    $config SetValue program_libmaker {ar crs}

    # Option processing for ar
    $config SetValue program_libmaker_option_obj {format \"%s\"}
    $config SetValue program_libmaker_option_out {format \"%s\"}

    # Use the selected compiler to control the linking.
    $config SetValue program_linker [lindex \
	    [$config GetValue program_compiler_c++] 0]

    # Linker option processing with g++ as linker
    $config SetValue program_linker_option_obj {format \"%s\"}
    $config SetValue program_linker_option_out {format "-o \"%s\""}
    $config SetValue program_linker_option_lib {format \"%s\"}
    $config SetValue program_linker_uses_-L-l {1}

    # Name formats on generated files
    $config SetValue script_filename_object {format %s.o}
    $config SetValue script_filename_static_library {format lib%s.a}
    $config SetValue script_filename_executable {format %s.exe}

    # The Cygwin distribution seems to have a bad TCL_RANLIB entry
    # Check it.
    if {[catch {$config GetValue TCL_RANLIB} ranlib]
	|| ![llength [auto_execok $ranlib]]} {
	$config SetValue TCL_RANLIB ranlib
    }
    unset ranlib
}
unset ccbasename

# String to pass to linker to pick up the Tcl and Tk libraries from
# the install directory.
$config SetValue TCL_LIB_SPEC \
        [list -L[file join [$config GetValue TCL_EXEC_PREFIX] lib] \
	-ltcl[$config GetValue \
	TCL_MAJOR_VERSION][$config GetValue TCL_MINOR_VERSION]]
$config SetValue TK_LIB_SPEC \
        [list -L[file join [$config GetValue TCL_EXEC_PREFIX] lib] \
	-ltk[$config GetValue \
	TK_MAJOR_VERSION][$config GetValue TK_MINOR_VERSION]]

# Additional libraries to use when linking against TCL, Tk
$config SetValue TCL_LIBS {-luser32}  ;# Needed by oc.cc for MessageBeep()
$config SetValue TK_LIBS {-luser32}

# Directory holding init.tcl.  Use this if environment variable
# TCL_LIBRARY is not set.
$config SetValue TCL_LIBRARY [file join [$config GetValue TCL_PREFIX] \
	share tcl[$config GetValue TCL_VERSION]]

########################################################################
unset config
